==> alone-frame-3.2.6.tgz: package/route/getVue.js <==
import alone from "../tool/alone.js";

import vue_list from "./vueList.js";

//生成动态路由
const create_local_array = function (view, group, index = 'index', route = [], is_index = false) {
    Object.keys(view).forEach((path) => {
        let is_group = false;
        if (alone.isset(group)) {
            const arr = path.split('/');
            Object.keys(group).forEach(k => {
                const value = alone.trim(group[k], '/');
                const key = k.split('/');
                const len = key.length;
                if (arr.length > len && arr.slice(0, len).join('/') == alone.trim(k, '/')) {
                    is_group = true;
                    let parent = route.find(r => r.path === value);
                    if (!parent) {
                        parent = {path: value, alias: value.split('/').slice(0, -1).join('/'), children: []};
                        route.push(parent);
                    }
                    if (value != path) {
                        parent.children.push({path: path});
                    }
                }
            });
        }
        if (is_group === false) {
            if (path === alone.trim(index || "index", '/')) {
                is_index = true;
                route.push({path: path, alias: '/'});
            } else {
                route.push({path: path});
            }
        }
    });
    if (is_index === false && alone.isset(route)) {
        route[0].alias = '/';
    }
    return route;
};

//合并路由配置
const merge_route = function (arr, array, merge = false, map = {}) {
    if (alone.isset(arr) && alone.isset(array)) {
        arr.forEach(v => (map[v.path] = {...v}));
        array.forEach(v => {
            const obj = map[v.path] || {};
            map[v.path] = merge ? {...obj, ...v} : {...v};
            if (v.children) {
                map[v.path].children = merge_route(obj.children || [], v.children, merge);
            }
        });
        return Object.values(map);
    } else if (alone.isset(array)) {
        return array;
    }
    return arr;
};

//生成路由array
const create_route = function (view, arr, array = []) {
    if (alone.isset(arr)) {
        arr = alone.is_object(arr) ? Object.values(arr) : arr;
        for (const val of arr) {
            const v = {...val};
            const path = alone.trim(v.path || '', '/');
            let component = v.component ? v.component : path;
            if (component) {
                if (alone.is_string(component) || alone.is_number(component)) {
                    component = view[alone.trim(component, '/')];
                }
                if (component) {
                    v.path = "/" + path;
                    (v.alias) && (v.alias = "/" + alone.trim(v.alias, '/'));
                    (!v.name) && (v.name = path.replace(/\./g, '_').replace(/\//g, '_'));
                    v.component = component;
                    (v.children) && (v.children = create_route(view, v.children));
                    array.push(v);
                }
            }
        }
    }
    return array;
};

//是否开启动态路由,默认首页,分组,...路由设置
export default function ({status, index, group, view}, ...array) {
    let route = [], routes = [];
    view = (alone.isset(view) ? view : vue_list) || {};
    const viewList = view.list;
    if (alone.isset(viewList)) {
        alone.isset(array) && array.forEach((arr) => (route = merge_route(route, arr, true)));
        route = (status || status === undefined) ? merge_route(create_local_array(viewList, group, index), route) : route;
        route = alone.isset(route) ? route : create_local_array(viewList, group, index);
        routes = create_route(viewList, route);
    }
    return {route: route, routes: routes, view: viewList};
}

==> alone-frame-3.4.4.tgz: package/route/getVue.js <==
import alone from "../tool/alone.js";

import vue_list from "./vueList.js";

//生成动态路由
const create_local_array = function (view, group, index = 'index', route = [], is_index = false) {
    Object.keys(view).forEach((path) => {
        let is_group = false;
        if (alone.isset(group)) {
            const arr = path.split('/');
            Object.keys(group).forEach(k => {
                const value = alone.trim(group[k], '/');
                const key = k.split('/');
                const len = key.length;
                if (arr.length > len && arr.slice(0, len).join('/') == alone.trim(k, '/')) {
                    is_group = true;
                    let parent = route.find(r => r.path === value);
                    if (!parent) {
                        parent = {path: value, alias: value.split('/').slice(0, -1).join('/'), children: []};
                        route.push(parent);
                    }
                    if (value != path) {
                        parent.children.push({path: path});
                    }
                }
            });
        }
        if (is_group === false) {
            if (path === alone.trim(index || "index", '/')) {
                is_index = true;
                route.push({path: path, alias: '/'});
            } else {
                route.push({path: path});
            }
        }
    });
    if (is_index === false && alone.isset(route)) {
        route[0].alias = '/';
    }
    return route;
};

//合并路由配置
const merge_route = function (arr, array, merge = false, map = {}) {
    if (alone.isset(arr) && alone.isset(array)) {
        arr.forEach(v => (map[v.path] = {...v}));
        array.forEach(v => {
            const obj = map[v.path] || {};
            map[v.path] = merge ? {...obj, ...v} : {...v};
            if (v.children) {
                map[v.path].children = merge_route(obj.children || [], v.children, merge);
            }
        });
        return Object.values(map);
    } else if (alone.isset(array)) {
        return array;
    }
    return arr;
};

//生成路由array
const create_route = function (view, arr, array = []) {
    if (alone.isset(arr)) {
        arr = alone.is_object(arr) ? Object.values(arr) : arr;
        for (const val of arr) {
            const v = {...val};
            const path = alone.trim(v.path || '', '/');
            let component = v.component ? v.component : path;
            if (component) {
                if (alone.is_string(component) || alone.is_number(component)) {
                    component = view[alone.trim(component, '/')];
                }
                if (component) {
                    v.path = "/" + path;
                    (v.alias) && (v.alias = "/" + alone.trim(v.alias, '/'));
                    (!v.name) && (v.name = path.replace(/\./g, '_').replace(/\//g, '_'));
                    v.component = component;
                    (v.children) && (v.children = create_route(view, v.children));
                    array.push(v);
                }
            }
        }
    }
    return array;
};

//是否开启动态路由,默认首页,分组,...路由设置
export default function ({status, index, group, view}, ...array) {
    let route = [], routes = [];
    const viewList = (alone.isset(view) ? view : vue_list) || {};
    if (alone.isset(viewList)) {
        alone.isset(array) && array.forEach((arr) => (route = merge_route(route, arr, true)));
        route = (status || status === undefined) ? merge_route(create_local_array(viewList, group, index), route) : route;
        route = alone.isset(route) ? route : create_local_array(viewList, group, index);
        routes = create_route(viewList, route);
    }
    return {route: route, routes: routes, view: viewList};
}
